passenger

package module
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 16, 2021 License: Apache-2.0 Imports: 10 Imported by: 0

README

Passenger Paketo Buildpack

gcr.io/paketo-buildpacks/passenger

The Passenger CNB sets the start command for a given ruby application that runs on a Passenger server.

Integration

This CNB writes a command, so there's currently no scenario we can imagine that you would need to require it as dependency. If a user likes to include some other functionality, it can be done independent of the Rake CNB without requiring a dependency of it.

To package this buildpack for consumption:

$ ./scripts/package.sh

This builds the buildpack's source using GOOS=linux by default. You can supply another value as the first argument to package.sh.

buildpack.yml Configurations

There are no extra configurations for this buildpack based on buildpack.yml.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Build

func Build(dependencyManager DependencyManager, clock chronos.Clock, logger scribe.Logger) packit.BuildFunc

func Detect

func Detect(gemfileParser Parser) packit.DetectFunc

Types

type BuildPlanMetadata

type BuildPlanMetadata struct {
	Launch bool `toml:"launch"`
}

type DependencyManager

type DependencyManager interface {
	Resolve(path, id, version, stack string) (postal.Dependency, error)
	Install(dependency postal.Dependency, cnbPath, layerPath string) error
}

type GemfileParser

type GemfileParser struct{}

func NewGemfileParser

func NewGemfileParser() GemfileParser

func (GemfileParser) Parse

func (p GemfileParser) Parse(path string) (bool, error)

type Parser

type Parser interface {
	Parse(path string) (hasPassenger bool, err error)
}

Directories

Path Synopsis

Jump to